summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author AJR <ajrhacker@users.noreply.github.com>2018-03-23 15:48:36 -0400
committer AJR <ajrhacker@users.noreply.github.com>2018-03-23 15:48:36 -0400
commit936b16a14710699a5a690cfa6eec5ddf8fdbce40 (patch)
tree6adaed432f9def4437baa8648d3df359e0293d5d
parentd3e80e1e78b14f613b4a7bc097eba252c8d60f8a (diff)
dec8.cpp: Revert ill-considered timing change that broke srdarwin (nw)
-rw-r--r--src/mame/drivers/dec8.cpp2
1 files changed, 1 insertions, 1 deletions
diff --git a/src/mame/drivers/dec8.cpp b/src/mame/drivers/dec8.cpp
index 5ed48a767b6..bc9d711032c 100644
--- a/src/mame/drivers/dec8.cpp
+++ b/src/mame/drivers/dec8.cpp
@@ -162,7 +162,7 @@ WRITE8_MEMBER(dec8_state::dec8_i8751_w)
case 0: /* High byte - SECIRQ is trigged on activating this latch */
m_i8751_value = (m_i8751_value & 0xff) | (data << 8);
m_mcu->set_input_line(MCS51_INT1_LINE, ASSERT_LINE);
- m_i8751_timer->adjust(m_mcu->clocks_to_attotime(3)); // 3 clocks not confirmed
+ m_i8751_timer->adjust(m_mcu->clocks_to_attotime(64)); // 64 clocks not confirmed
break;
case 1: /* Low byte */
m_i8751_value = (m_i8751_value & 0xff00) | data;